==> com.liferay.layout.content.page.editor.web-2.0.122-sources.jar: META-INF/resources/page_editor/app/actions/types.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

export const ADD_FRAGMENT_COMPOSITION = 'ADD_FRAGMENT_COMPOSITION';
export const ADD_FRAGMENT_ENTRY_LINKS = 'ADD_FRAGMENT_ENTRY_LINKS';
export const ADD_FRAGMENT_ENTRY_LINK_COMMENT =
	'ADD_FRAGMENT_ENTRY_LINK_COMMENT';
export const ADD_ITEM = 'ADD_ITEM';
export const ADD_MAPPED_INFO_ITEM = 'ADD_MAPPED_INFO_ITEM';
export const ADD_REDO_ACTION = 'ADD_REDO_ACTION';
export const ADD_UNDO_ACTION = 'ADD_UNDO_ACTION';
export const CHANGE_MASTER_LAYOUT = 'CHANGE_MASTER_LAYOUT';
export const DELETE_FRAGMENT_ENTRY_LINK_COMMENT =
	'DELETE_FRAGMENT_ENTRY_LINK_COMMENT';
export const DELETE_ITEM = 'DELETE_ITEM';
export const DELETE_WIDGETS = 'DELETE_WIDGETS';
export const DUPLICATE_ITEM = 'DUPLICATE_ITEM';
export const EDIT_FRAGMENT_ENTRY_LINK_COMMENT =
	'EDIT_FRAGMENT_ENTRY_LINK_COMMENT';
export const INIT = 'INIT';
export const LOAD_REDUCER = 'LOAD_REDUCER';
export const MOVE_ITEM = 'MOVE_ITEM';
export const SET_FRAGMENT_EDITABLES = 'SET_FRAGMENT_EDITABLES';
export const SWITCH_SIDEBAR_PANEL = 'SWITCH_SIDEBAR_PANEL';
export const SWITCH_VIEWPORT_SIZE = 'SWITCH_VIEWPORT_SIZE';
export const TOGGLE_PERMISSION = 'TOGGLE_PERMISSION';
export const TOGGLE_SHOW_RESOLVED_COMMENTS = 'TOGGLE_SHOW_RESOLVED_COMMENTS';
export const UNLOAD_REDUCER = 'UNLOAD_REDUCER';
export const UPDATE_COL_SIZE = 'UPDATE_COL_SIZE';
export const UPDATE_EDITABLE_VALUES = 'UPDATE_EDITABLE_VALUES';
export const UPDATE_ITEM_CONFIG = 'UPDATE_ITEM_CONFIG';
export const UPDATE_FRAGMENT_ENTRY_LINK_CONFIGURATION =
	'UPDATE_FRAGMENT_ENTRY_LINK_CONFIGURATION';
export const UPDATE_FRAGMENT_ENTRY_LINK_CONTENT =
	'UPDATE_FRAGMENT_ENTRY_LINK_CONTENT';
export const UPDATE_LANGUAGE_ID = 'UPDATE_LANGUAGE_ID';
export const UPDATE_LAYOUT_DATA = 'UPDATE_LAYOUT_DATA';
export const UPDATE_NETWORK = 'UPDATE_NETWORK';
export const UPDATE_REDO_ACTIONS = 'UPDATE_REDO_ACTIONS';
export const UPDATE_ROW_COLUMNS = 'UPDATE_ROW_COLUMNS';
export const UPDATE_UNDO_ACTIONS = 'UPDATE_UNDO_ACTIONS';
export const UPDATE_PAGE_CONTENTS = 'UPDATE_PAGE_CONTENTS';

==> com.liferay.layout.content.page.editor.web-3.0.106-sources.jar: META-INF/resources/page_editor/app/actions/types.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

export const ADD_FRAGMENT_COMPOSITION = 'ADD_FRAGMENT_COMPOSITION';
export const ADD_FRAGMENT_ENTRY_LINKS = 'ADD_FRAGMENT_ENTRY_LINKS';
export const ADD_FRAGMENT_ENTRY_LINK_COMMENT =
	'ADD_FRAGMENT_ENTRY_LINK_COMMENT';
export const ADD_ITEM = 'ADD_ITEM';
export const ADD_MAPPED_INFO_ITEM = 'ADD_MAPPED_INFO_ITEM';
export const ADD_MAPPING_FIELDS = 'ADD_MAPPING_FIELDS';
export const ADD_REDO_ACTION = 'ADD_REDO_ACTION';
export const ADD_UNDO_ACTION = 'ADD_UNDO_ACTION';
export const CHANGE_MASTER_LAYOUT = 'CHANGE_MASTER_LAYOUT';
export const DELETE_FRAGMENT_ENTRY_LINK_COMMENT =
	'DELETE_FRAGMENT_ENTRY_LINK_COMMENT';
export const DELETE_ITEM = 'DELETE_ITEM';
export const DUPLICATE_ITEM = 'DUPLICATE_ITEM';
export const EDIT_FRAGMENT_ENTRY_LINK_COMMENT =
	'EDIT_FRAGMENT_ENTRY_LINK_COMMENT';
export const INIT = 'INIT';
export const LOAD_REDUCER = 'LOAD_REDUCER';
export const MOVE_ITEM = 'MOVE_ITEM';
export const SWITCH_SIDEBAR_PANEL = 'SWITCH_SIDEBAR_PANEL';
export const SWITCH_VIEWPORT_SIZE = 'SWITCH_VIEWPORT_SIZE';
export const TOGGLE_PERMISSION = 'TOGGLE_PERMISSION';
export const TOGGLE_SHOW_RESOLVED_COMMENTS = 'TOGGLE_SHOW_RESOLVED_COMMENTS';
export const UNLOAD_REDUCER = 'UNLOAD_REDUCER';
export const UPDATE_COL_SIZE = 'UPDATE_COL_SIZE';
export const UPDATE_COLLECTION_DISPLAY_COLLECTION =
	'UPDATE_COLLECTION_DISPLAY_COLLECTION';
export const UPDATE_EDITABLE_VALUES = 'UPDATE_EDITABLE_VALUES';
export const UPDATE_ITEM_CONFIG = 'UPDATE_ITEM_CONFIG';
export const UPDATE_ITEM_LOCAL_CONFIG = 'UPDATE_ITEM_LOCAL_CONFIG';
export const UPDATE_FRAGMENT_ENTRY_LINK_CONFIGURATION =
	'UPDATE_FRAGMENT_ENTRY_LINK_CONFIGURATION';
export const UPDATE_FRAGMENT_ENTRY_LINK_CONTENT =
	'UPDATE_FRAGMENT_ENTRY_LINK_CONTENT';
export const UPDATE_LANGUAGE_ID = 'UPDATE_LANGUAGE_ID';
export const UPDATE_LAYOUT_DATA = 'UPDATE_LAYOUT_DATA';
export const UPDATE_NETWORK = 'UPDATE_NETWORK';
export const UPDATE_REDO_ACTIONS = 'UPDATE_REDO_ACTIONS';
export const UPDATE_ROW_COLUMNS = 'UPDATE_ROW_COLUMNS';
export const UPDATE_UNDO_ACTIONS = 'UPDATE_UNDO_ACTIONS';
export const UPDATE_PAGE_CONTENTS = 'UPDATE_PAGE_CONTENTS';
export const UPDATE_PREVIEW_IMAGE = 'UPDATE_PREVIEW_IMAGE';
